from distutils.core import setup
setup(
        name='printline',
        version='1.0.0',
        py_modules=['printline'],
        author='lzwxg',
        author_email='lzwxg@126.com',
        url='http://www.baidu.com',
        description='A simple ',
    )
    
